@@ -1003,8 +1003,8 @@ class GetServiceStatusResponse(AbstractModel):
         :type ServiceEnabled: bool
         :param InvalidType: 服务不可用类型： 0-未购买，1-正常， 2-欠费停服， 3-资源释放。
         :type InvalidType: int
-        :param AccessKeyEscrowEnabled: true表示用户已经可以使用云API密钥安全托管功能，
-false表示用户暂时不能使用云API密钥安全托管功能。
+        :param AccessKeyEscrowEnabled: true表示用户已经可以使用密钥安全托管功能，
+false表示用户暂时不能使用密钥安全托管功能。
         :type AccessKeyEscrowEnabled: bool
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -1381,7 +1381,7 @@ class RotateProductSecretResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param FlowID: 当凭据类型为云产品凭据时（即SecretType为1，如Mysq、Tdsql等托管凭据）此字段有效，返回轮转异步任务ID号。
+        :param FlowID: 当凭据类型为云产品凭据时（即SecretType为1，如MySQL、Tdsql等托管凭据）此字段有效，返回轮转异步任务ID号。
         :type FlowID: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
